@@ -125,6 +125,69 @@ def import_keyring():
     # guessing what to block and extending the list below.
     mod, was_imported_now = meu.direct_import_ext(
         "keyring", [
+            "cryptography.hazmat._oid",
+            "cryptography.hazmat.backends",
+            "cryptography.hazmat.backends.openssl",
+            "cryptography.hazmat.backends.openssl.aead",
+            "cryptography.hazmat.backends.openssl.backend",
+            "cryptography.hazmat.backends.openssl.ciphers",
+            "cryptography.hazmat.backends.openssl.cmac",
+            "cryptography.hazmat.backends.openssl.dh",
+            "cryptography.hazmat.backends.openssl.dsa",
+            "cryptography.hazmat.backends.openssl.ec",
+            "cryptography.hazmat.backends.openssl.ed25519",
+            "cryptography.hazmat.backends.openssl.ed448",
+            "cryptography.hazmat.backends.openssl.hashes",
+            "cryptography.hazmat.backends.openssl.hmac",
+            "cryptography.hazmat.backends.openssl.poly1305",
+            "cryptography.hazmat.backends.openssl.rsa",
+            "cryptography.hazmat.backends.openssl.utils",
+            "cryptography.hazmat.backends.openssl.x25519",
+            "cryptography.hazmat.backends.openssl.x448",
+            "cryptography.hazmat.bindings",
+            "cryptography.hazmat.bindings._openssl",
+            "cryptography.hazmat.bindings._openssl.lib",
+            "cryptography.hazmat.bindings._rust",
+            "cryptography.hazmat.bindings.openssl",
+            "cryptography.hazmat.bindings.openssl._conditional",
+            "cryptography.hazmat.bindings.openssl.binding",
+            "cryptography.hazmat.primitives",
+            "cryptography.hazmat.primitives._asymmetric",
+            "cryptography.hazmat.primitives._cipheralgorithm",
+            "cryptography.hazmat.primitives._serialization",
+            "cryptography.hazmat.primitives.asymmetric",
+            "cryptography.hazmat.primitives.asymmetric.dh",
+            "cryptography.hazmat.primitives.asymmetric.dsa",
+            "cryptography.hazmat.primitives.asymmetric.ec",
+            "cryptography.hazmat.primitives.asymmetric.ed25519",
+            "cryptography.hazmat.primitives.asymmetric.ed448",
+            "cryptography.hazmat.primitives.asymmetric.padding",
+            "cryptography.hazmat.primitives.asymmetric.rsa",
+            "cryptography.hazmat.primitives.asymmetric.types",
+            "cryptography.hazmat.primitives.asymmetric.utils",
+            "cryptography.hazmat.primitives.asymmetric.x25519",
+            "cryptography.hazmat.primitives.asymmetric.x448",
+            "cryptography.hazmat.primitives.ciphers",
+            "cryptography.hazmat.primitives.ciphers.algorithms",
+            "cryptography.hazmat.primitives.ciphers.base",
+            "cryptography.hazmat.primitives.ciphers.modes",
+            "cryptography.hazmat.primitives.constant_time",
+            "cryptography.hazmat.primitives.hashes",
+            "cryptography.hazmat.primitives.kdf",
+            "cryptography.hazmat.primitives.kdf.scrypt",
+            "cryptography.hazmat.primitives.serialization",
+            "cryptography.hazmat.primitives.serialization.base",
+            "cryptography.hazmat.primitives.serialization.pkcs12",
+            "cryptography.hazmat.primitives.serialization.pkcs7",
+            "cryptography.hazmat.primitives.serialization.ssh",
+            "cryptography.utils",
+            "cryptography.x509",
+            "cryptography.x509.base",
+            "cryptography.x509.certificate_transparency",
+            "cryptography.x509.extensions",
+            "cryptography.x509.general_name",
+            "cryptography.x509.name",
+            "cryptography.x509.oid",
             "gobject._gobject",
             "configparser",
             "json",
